@@ -105,7 +105,9 @@ class PageNumberPaginationExtra(PaginationBase):
         )
 
     @classmethod
-    def get_response_schema(cls, response_schema: Type[Schema]) -> Type[Schema]:
+    def get_response_schema(
+        cls, response_schema: Union[Schema, Type[Schema]]
+    ) -> Type[Schema]:
         if sys.version_info >= (3, 8):
             return PaginatedResponseSchema[response_schema]
         return get_paginated_response_schema(response_schema)
@@ -175,7 +177,9 @@ def _inject_pagination(
             func_kwargs.pop(paginator_kwargs_name)
 
         items = func(controller, *args, **func_kwargs)
-        assert controller.context.request, "Request object is None"
+        assert (
+            controller.context and controller.context.request
+        ), "Request object is None"
         return paginator.paginate_queryset(items, controller.context.request, **kw)
 
     view_with_pagination._ninja_contribute_args = [  # type: ignore
