@@ -2,6 +2,7 @@
 Copied from DRF
 Provides a set of pluggable permission policies.
 """
+from abc import ABC, ABCMeta, abstractmethod
 from typing import TYPE_CHECKING, Any, Generic, Tuple, Type, TypeVar
 
 from django.http import HttpRequest
@@ -32,12 +33,42 @@ class OperationHolderMixin:
         return SingleOperandHolder(NOT, self)  # type: ignore
 
 
+class BasePermissionMetaclass(OperationHolderMixin, ABCMeta):
+    pass
+
+
+class BasePermission(ABC, metaclass=BasePermissionMetaclass):
+    """
+    A base class from which all permission classes should inherit.
+    """
+
+    message: Any = None
+
+    @abstractmethod
+    def has_permission(self, request: HttpRequest, controller: "APIController") -> bool:
+        """
+        Return `True` if permission is granted, `False` otherwise.
+        """
+        return True
+
+    def has_object_permission(
+        self, request: HttpRequest, controller: "APIController", obj: Any
+    ) -> bool:
+        """
+        Return `True` if permission is granted, `False` otherwise.
+        """
+        return True
+
+
 class SingleOperandHolder(OperationHolderMixin, Generic[T]):
-    def __init__(self, operator_class: T, op1_class: Type["BasePermission"]) -> None:
+    def __init__(
+        self, operator_class: Type[BasePermission], op1_class: Type[BasePermission]
+    ) -> None:
+        super().__init__()
         self.operator_class = operator_class
         self.op1_class = op1_class
 
-    def __call__(self, *args: Tuple[Any], **kwargs: DictStrAny) -> T:
+    def __call__(self, *args: Tuple[Any], **kwargs: DictStrAny) -> BasePermission:
         op1 = self.op1_class()
         return self.operator_class(op1)  # type: ignore
 
@@ -45,7 +76,7 @@ class SingleOperandHolder(OperationHolderMixin, Generic[T]):
 class OperandHolder(OperationHolderMixin, Generic[T]):
     def __init__(
         self,
-        operator_class: T,
+        operator_class: Type["BasePermission"],
         op1_class: Type["BasePermission"],
         op2_class: Type["BasePermission"],
     ) -> None:
@@ -53,13 +84,13 @@ class OperandHolder(OperationHolderMixin, Generic[T]):
         self.op1_class = op1_class
         self.op2_class = op2_class
 
-    def __call__(self, *args: Tuple[Any], **kwargs: DictStrAny) -> T:
+    def __call__(self, *args: Tuple[Any], **kwargs: DictStrAny) -> BasePermission:
         op1 = self.op1_class()
         op2 = self.op2_class()
         return self.operator_class(op1, op2)  # type: ignore
 
 
-class AND:
+class AND(BasePermission):
     def __init__(self, op1: "BasePermission", op2: "BasePermission") -> None:
         self.op1 = op1
         self.op2 = op2
@@ -77,7 +108,7 @@ class AND:
         ) and self.op2.has_object_permission(request, controller, obj)
 
 
-class OR:
+class OR(BasePermission):
     def __init__(self, op1: "BasePermission", op2: "BasePermission") -> None:
         self.op1 = op1
         self.op2 = op2
@@ -95,7 +126,7 @@ class OR:
         ) or self.op2.has_object_permission(request, controller, obj)
 
 
-class NOT:
+class NOT(BasePermission):
     def __init__(self, op1: "BasePermission") -> None:
         self.op1 = op1
 
@@ -106,29 +137,3 @@ class NOT:
         self, request: HttpRequest, controller: "APIController", obj: Any
     ) -> bool:
         return not self.op1.has_object_permission(request, controller, obj)
-
-
-class BasePermissionMetaclass(OperationHolderMixin, type):
-    pass
-
-
-class BasePermission(metaclass=BasePermissionMetaclass):
-    """
-    A base class from which all permission classes should inherit.
-    """
-
-    message = None
-
-    def has_permission(self, request: HttpRequest, controller: "APIController") -> bool:
-        """
-        Return `True` if permission is granted, `False` otherwise.
-        """
-        return True
-
-    def has_object_permission(
-        self, request: HttpRequest, controller: "APIController", obj: Any
-    ) -> bool:
-        """
-        Return `True` if permission is granted, `False` otherwise.
-        """
-        return True
